NodeKind

Enum NodeKind 

#[non_exhaustive]
pub enum NodeKind {
Show 28 variants Repository, File, Module, Package, Function, Method, Struct, Enum, Trait, TypeAlias, Constant, Static, Service, Endpoint, Table, Column, Topic, ConsumerGroup, Exchange, Queue, Binding, Collection, Index, KubernetesResource, Container, ConfigKey, Unknown, Custom(String),
}
Semantic role of a graph node.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Repository



File



Module



Package



Function



Method



Struct



Enum



Trait



TypeAlias



Constant



Static



Service



Endpoint



Table



Column



Topic



ConsumerGroup



Exchange



Queue



Binding



Collection



Index



KubernetesResource



Container



ConfigKey



Unknown



Custom(String)

Implementations

Source

impl NodeKind

pub fn as_str(&self) -> &str

pub fn custom(value: impl Into<String>) -> Result<NodeKind, GraphError>

Creates an application-specific kind without changing this crate.

Errors

Returns an error for empty values or surrounding whitespace.